about summary refs log tree commit diff
path: root/sysdeps/vax
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/vax')
-rw-r--r--sysdeps/vax/memchr.s2
-rw-r--r--sysdeps/vax/strchr.s4
-rw-r--r--sysdeps/vax/strncmp.s4
-rw-r--r--sysdeps/vax/strrchr.s2
4 files changed, 6 insertions, 6 deletions
diff --git a/sysdeps/vax/memchr.s b/sysdeps/vax/memchr.s
index c7793fb5f8..b81c2bcf87 100644
--- a/sysdeps/vax/memchr.s
+++ b/sysdeps/vax/memchr.s
@@ -36,7 +36,7 @@
 #endif /* LIBC_SCCS and not lint */
 
 /*
- * Find the first occurence of c in the memory at cp (length n).
+ * Find the first occurrence of c in the memory at cp (length n).
  * Return pointer to match or null pointer.
  *
  * This code optimises the usual case (0 < n < 65535).
diff --git a/sysdeps/vax/strchr.s b/sysdeps/vax/strchr.s
index 1683f564e2..70025cce6e 100644
--- a/sysdeps/vax/strchr.s
+++ b/sysdeps/vax/strchr.s
@@ -36,7 +36,7 @@
 #endif /* LIBC_SCCS and not lint */
 
 /*
- * Find the first occurence of c in the string cp.
+ * Find the first occurrence of c in the string cp.
  * Return pointer to match or null pointer.
  *
  * char *
@@ -58,7 +58,7 @@ ENTRY(strchr, 0)
  */
 	movab	tbl,r3		/* r3 = base of table */
 	bbss	$0,(r3),Lreent	/* ensure not reentering */
-	movab	(r3)[r2],r5	
+	movab	(r3)[r2],r5
 	incb	(r5)		/* mark both '\0' and c */
 0:
 	scanc	r4,(r1),(r3),$1	/* look for c or '\0' */
diff --git a/sysdeps/vax/strrchr.s b/sysdeps/vax/strrchr.s
index dffcddaef0..87313445c9 100644
--- a/sysdeps/vax/strrchr.s
+++ b/sysdeps/vax/strrchr.s
@@ -36,7 +36,7 @@
 #endif /* LIBC_SCCS and not lint */
 
 /*
- * Find the last occurence of c in the string cp.
+ * Find the last occurrence of c in the string cp.
  * Return pointer to match or null pointer.
  *
  * char *
diff --git a/sysdeps/vax/strncmp.s b/sysdeps/vax/strncmp.s
index e5bfcf2a73..0758bd8729 100644
--- a/sysdeps/vax/strncmp.s
+++ b/sysdeps/vax/strncmp.s
@@ -53,14 +53,14 @@ ENTRY(strncmp, 0)
 	movl	4(ap),r1	# r1 = s1
 	movq	8(ap),r3	# r3 = s2; r4 = n
 1:
-	clrl	r5		# calculate min bytes to next page boundry
+	clrl	r5		# calculate min bytes to next page boundary
 	subb3	r1,$255,r5	# r5 = (bytes - 1) to end of page for s1
 	subb3	r3,$255,r0	# r0 = (bytes - 1) to end of page for s2
 	cmpb	r0,r5		# r5 = min(r0, r5);
 	bgtru	2f
 	movb	r0,r5
 2:
-	incl	r5		# r5 = min bytes to next page boundry
+	incl	r5		# r5 = min bytes to next page boundary
 	cmpl	r4,r5		# r5 = min(n, r5);
 	bgeq	3f
 	movl	r4,r5